<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Duplicate</name>
    <message>
        <location filename="../DuplicateInit.js" line="+2"/>
        <source>&amp;Duplicate</source>
        <translation>&amp;Duplique</translation>
    </message>
    <message>
        <source>1 entity duplicated</source>
        <translation type="vanished">Uma entidade foi duplicada</translation>
    </message>
    <message>
        <source>%1 entities duplicated</source>
        <translation type="vanished">%1 entidades foram duplicados</translation>
    </message>
    <message numerus="yes">
        <location filename="../Duplicate.js" line="+54"/>
        <source>%n entity/ies duplicated</source>
        <translation>
            <numerusform>Uma entidade foi duplicada</numerusform>
            <numerusform>%n entidades foram duplicados</numerusform>
        </translation>
    </message>
</context>
</TS>
